==> qdl_1.0.3.tar.gz: qdl-1.0.3/qdl-app/src/maemo4/categorysettingstab.cpp <==
#include "categorysettingstab.h"
#include "../shared/categoriesmodel.h"
#include <QGridLayout>
#include <QLabel>
#include <QFileDialog>
#include <QTreeView>
#include <QPushButton>
#include <QLineEdit>
#include <QDesktopServices>

CategorySettingsTab::CategorySettingsTab(QWidget *parent) :
    QWidget(parent),
    m_model(new CategoriesModel(this)),
    m_view(new QTreeView(this)),
    m_contextMenu(new QMenu(this)),
    m_editAction(m_contextMenu->addAction(tr("Edit"), this, SLOT(editCategory()))),
    m_removeAction(m_contextMenu->addAction(tr("Remove"), this, SLOT(removeCategory()))),
    m_nameEdit(new QLineEdit(this)),
    m_pathEdit(new QLineEdit(this)),
    m_browseButton(new QPushButton(tr("Browse"), this)),
    m_doneButton(new QPushButton(tr("Save"), this))
{
    QGridLayout *grid = new QGridLayout(this);
    grid->addWidget(m_view, 0, 0, 3, 4);
    grid->addItem(new QSpacerItem(10, 10, QSizePolicy::Minimum, QSizePolicy::Expanding), 2, 4);
    grid->addWidget(new QLabel(tr("Add/edit category"), this), 3, 0);
    grid->addWidget(new QLabel(QString("%1:").arg(tr("Name")), this), 4, 0);
    grid->addWidget(m_nameEdit, 4, 1);
    grid->addWidget(new QLabel(QString("%1:").arg(tr("Download path")), this), 5, 0);
    grid->addWidget(m_pathEdit, 5, 1);
    grid->addWidget(m_browseButton, 5, 2);
    grid->addWidget(m_doneButton, 6, 0);

    m_doneButton->setEnabled(false);

    m_view->setModel(m_model);
    m_view->setRootIsDecorated(false);
    m_view->setSelectionBehavior(QTreeView::SelectRows);
    m_view->setEditTriggers(QTreeView::NoEditTriggers);
    m_view->setExpandsOnDoubleClick(false);
    m_view->setItemsExpandable(false);
    m_view->setColumnWidth(0, 200);
    m_view->setContextMenuPolicy(Qt::CustomContextMenu);

    this->connect(m_view, SIGNAL(clicked(QModelIndex)), this, SLOT(editCategory()));
    this->connect(m_view, SIGNAL(activated(QModelIndex)), this, SLOT(editCategory()));
    this->connect(m_view, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(showContextMenu(QPoint)));
    this->connect(m_doneButton, SIGNAL(clicked()), this, SLOT(addCategory()));
    this->connect(m_browseButton, SIGNAL(clicked()), this, SLOT(showFolderDialog()));
    this->connect(m_nameEdit, SIGNAL(textChanged(QString)), this, SLOT(onCategoryEditChanged()));
    this->connect(m_pathEdit, SIGNAL(textChanged(QString)), this, SLOT(onCategoryEditChanged()));
}

void CategorySettingsTab::showContextMenu(const QPoint &pos) {
    m_contextMenu->popup(m_view->mapToGlobal(pos), m_editAction);
}

void CategorySettingsTab::addCategory() {
    m_model->addCategory(m_nameEdit->text(), m_pathEdit->text());

    m_nameEdit->clear();
    m_pathEdit->clear();
}

void CategorySettingsTab::removeCategory() {
    if (m_view->currentIndex().isValid()) {
        m_model->removeCategory(m_view->currentIndex().row());
    }
}

void CategorySettingsTab::editCategory() {
    QModelIndex index = m_view->currentIndex();

    if (index.isValid()) {
        m_nameEdit->setText(index.data(CategoriesModel::NameRole).toString());
        m_pathEdit->setText(index.data(CategoriesModel::PathRole).toString());
    }
}

void CategorySettingsTab::showFolderDialog() {
    QString currentPath = m_pathEdit->text().isEmpty() ? QDesktopServices::storageLocation(QDesktopServices::HomeLocation) : m_pathEdit->text();
    QString path = QFileDialog::getExistingDirectory(this, tr("Download path"), currentPath);

    if (!path.isEmpty()) {
        m_pathEdit->setText(path);
    }
}

void CategorySettingsTab::onCategoryEditChanged() {
    m_doneButton->setEnabled((!m_nameEdit->text().isEmpty()) && (!m_pathEdit->text().isEmpty()));
}

==> qdl_1.0.5.tar.gz: qdl-1.0.5/qdl-app/src/maemo4/categorysettingstab.cpp <==
#include "categorysettingstab.h"
#include "newcategorydialog.h"
#include "../shared/categoriesmodel.h"
#include <QVBoxLayout>
#include <QTreeView>
#include <QMenu>
#include <QPushButton>

CategorySettingsTab::CategorySettingsTab(QWidget *parent) :
    QWidget(parent),
    m_model(new CategoriesModel(this)),
    m_view(new QTreeView(this)),
    m_contextMenu(new QMenu(this)),
    m_editAction(m_contextMenu->addAction(tr("Edit"), this, SLOT(editCategory()))),
    m_removeAction(m_contextMenu->addAction(tr("Remove"), this, SLOT(removeCategory()))),
    m_newButton(new QPushButton(tr("New"), this))
{
    m_view->setModel(m_model);
    m_view->setRootIsDecorated(false);
    m_view->setSelectionBehavior(QTreeView::SelectRows);
    m_view->setEditTriggers(QTreeView::NoEditTriggers);
    m_view->setExpandsOnDoubleClick(false);
    m_view->setItemsExpandable(false);
    m_view->setColumnWidth(0, 200);
    m_view->setContextMenuPolicy(Qt::CustomContextMenu);

    QVBoxLayout *vbox = new QVBoxLayout(this);
    vbox->addWidget(m_view);
    vbox->addWidget(m_newButton, 0, Qt::AlignRight);

    this->connect(m_view, SIGNAL(clicked(QModelIndex)), this, SLOT(editCategory()));
    this->connect(m_view, SIGNAL(activated(QModelIndex)), this, SLOT(editCategory()));
    this->connect(m_view, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(showContextMenu(QPoint)));
    this->connect(m_newButton, SIGNAL(clicked()), this, SLOT(addCategory()));
}

void CategorySettingsTab::showContextMenu(const QPoint &pos) {
    m_contextMenu->popup(m_view->mapToGlobal(pos), m_editAction);
}

void CategorySettingsTab::addCategory() {
    NewCategoryDialog *dialog = new NewCategoryDialog(this);
    dialog->open();
    this->connect(dialog, SIGNAL(addCategory(QString,QString)), m_model, SLOT(addCategory(QString,QString)));
}

void CategorySettingsTab::removeCategory() {
    if (m_view->currentIndex().isValid()) {
        m_model->removeCategory(m_view->currentIndex().row());
    }
}

void CategorySettingsTab::editCategory() {
    QModelIndex index = m_view->currentIndex();

    if (index.isValid()) {
        NewCategoryDialog *dialog = new NewCategoryDialog(this);
        dialog->setWindowTitle(tr("Edit category"));
        dialog->setName(index.data(CategoriesModel::NameRole).toString());
        dialog->setPath(index.data(CategoriesModel::PathRole).toString());
        dialog->open();
        this->connect(dialog, SIGNAL(addCategory(QString,QString)), m_model, SLOT(addCategory(QString,QString)));
    }
}
